@@ -22,7 +22,7 @@
 #'
 #' @inheritSection aemet_daily_clim API Key
 #'
-#' @return A tibble or a `sf` object
+#' @return A \CRANpkg{tibble} or a \CRANpkg{sf} object
 #'
 #' @examplesIf aemet_detect_api_key()
 #'
@@ -30,13 +30,16 @@
 #' obs <- aemet_monthly_clim(station = c("9434", "3195"), year = 2000)
 #' glimpse(obs)
 #' @export
-aemet_monthly_clim <- function(station = NULL, year = 2020, verbose = FALSE,
-                               return_sf = FALSE) {
+aemet_monthly_clim <- function(station = NULL,
+                               year = as.integer(format(Sys.Date(), "%Y")),
+                               verbose = FALSE,
+                               return_sf = FALSE, extract_metadata = FALSE) {
   # Validate inputs----
   if (is.null(station)) {
     stop("Station can't be missing")
   }
   station <- as.character(station)
+  if (isTRUE(extract_metadata)) station <- station[1]
 
   if (!is.numeric(year)) {
     stop("Year need to be numeric")
@@ -59,11 +62,21 @@ aemet_monthly_clim <- function(station = NULL, year = 2020, verbose = FALSE,
         station[i]
       )
 
-    final_result <-
-      dplyr::bind_rows(final_result, get_data_aemet(apidest, verbose))
+    if (isTRUE(extract_metadata)) {
+      final_result <- get_metadata_aemet(
+        apidest = apidest,
+        verbose = verbose
+      )
+    } else {
+      final_result <-
+        dplyr::bind_rows(final_result, get_data_aemet(apidest, verbose))
+    }
   }
 
   final_result <- dplyr::distinct(final_result)
+  if (isTRUE(extract_metadata)) {
+    return(final_result)
+  }
 
   # Guess formats
   final_result <-
@@ -92,8 +105,14 @@ aemet_monthly_clim <- function(station = NULL, year = 2020, verbose = FALSE,
 #' @param end Numeric value as end year (format: YYYY).
 #'
 #' @export
-aemet_monthly_period <- function(station = NULL, start = 2018, end = 2020,
-                                 verbose = FALSE, return_sf = FALSE) {
+aemet_monthly_period <- function(station = NULL,
+                                 start = as.integer(format(
+                                   Sys.Date(),
+                                   "%Y"
+                                 )),
+                                 end = start,
+                                 verbose = FALSE, return_sf = FALSE,
+                                 extract_metadata = FALSE) {
   # Validate inputs----
   if (is.null(station)) {
     stop("Station can't be missing")
@@ -106,6 +125,13 @@ aemet_monthly_period <- function(station = NULL, start = 2018, end = 2020,
   if (!is.numeric(end)) {
     stop("End year need to be numeric")
   }
+
+  if (isTRUE(extract_metadata)) {
+    y <- format(Sys.Date(), "%Y")
+    start <- as.numeric(y)
+    end <- as.numeric(y)
+  }
+
   # The rest of parameters are validated in aemet_monthly_clim
 
   final_result <- NULL
@@ -116,11 +142,15 @@ aemet_monthly_period <- function(station = NULL, start = 2018, end = 2020,
       station = station,
       year = y,
       verbose = verbose,
-      return_sf = FALSE
+      return_sf = FALSE,
+      extract_metadata = extract_metadata
     )
 
     final_result <- dplyr::bind_rows(final_result, this_y)
   }
+  if (isTRUE(extract_metadata)) {
+    return(final_result)
+  }
 
   # Check spatial----
   if (return_sf) {
@@ -142,8 +172,11 @@ aemet_monthly_period <- function(station = NULL, start = 2018, end = 2020,
 #' @rdname aemet_monthly
 #'
 #' @export
-aemet_monthly_period_all <- function(start = 2019, end = 2020,
-                                     verbose = FALSE, return_sf = FALSE) {
+aemet_monthly_period_all <- function(
+    start = as.integer(format(Sys.Date(), "%Y")),
+    end = start,
+    verbose = FALSE, return_sf = FALSE,
+    extract_metadata = FALSE) {
   # Validate inputs----
   if (is.null(start)) {
     stop("Start year can't be missing")
@@ -163,9 +196,11 @@ aemet_monthly_period_all <- function(start = 2019, end = 2020,
   # The rest of parameters are validated on aemet_monthly_clim
 
   # Get stations----
-  stations <-
-    aemet_stations(verbose = verbose)
-
+  if (isTRUE(extract_metadata)) {
+    stations <- data.frame(indicativo = default_station)
+  } else {
+    stations <- aemet_stations(verbose = verbose)
+  }
   if (verbose) {
     message("Requesting ", nrow(stations), " stations")
   }
@@ -181,10 +216,14 @@ aemet_monthly_period_all <- function(start = 2019, end = 2020,
       start = start,
       end = end,
       verbose = verbose,
-      return_sf = FALSE
+      return_sf = FALSE,
+      extract_metadata = extract_metadata
     )
     final_result <- dplyr::bind_rows(final_result, data_recover)
   }
+  if (isTRUE(extract_metadata)) {
+    return(final_result)
+  }
   # Check spatial----
   if (return_sf) {
     # Coordinates from stations
